@@ -1,8 +1,7 @@
 package segments
 
 type Cmake struct {
-	Dummy struct{}
-	language
+	Language
 }
 
 func (c *Cmake) Template() string {
@@ -11,14 +10,15 @@ func (c *Cmake) Template() string {
 
 func (c *Cmake) Enabled() bool {
 	c.extensions = []string{"*.cmake", "CMakeLists.txt"}
-	c.commands = []*cmd{
-		{
+	c.tooling = map[string]*cmd{
+		"cmake": {
 			executable: "cmake",
 			args:       []string{"--version"},
 			regex:      `cmake version (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+)))`,
 		},
 	}
+	c.defaultTooling = []string{"cmake"}
 	c.versionURLTemplate = "https://cmake.org/cmake/help/v{{ .Major }}.{{ .Minor }}"
 
-	return c.language.Enabled()
+	return c.Language.Enabled()
 }
