@@ -1,8 +1,7 @@
 package segments
 
 type Fortran struct {
-	Dummy struct{}
-	language
+	Language
 }
 
 func (f *Fortran) Template() string {
@@ -19,13 +18,14 @@ func (f *Fortran) Enabled() bool {
 		"*.F03", "*.F08",
 		"fpm.toml",
 	}
-	f.commands = []*cmd{
-		{
+	f.tooling = map[string]*cmd{
+		"gfortran": {
 			executable: "gfortran",
 			args:       []string{"--version"},
 			regex:      `GNU Fortran \(.*\) (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+)))`,
 		},
 	}
+	f.defaultTooling = []string{"gfortran"}
 
-	return f.language.Enabled()
+	return f.Language.Enabled()
 }
