@@ -21,17 +21,18 @@ func (g *Golang) Template() string {
 
 func (g *Golang) Enabled() bool {
 	g.extensions = []string{"*.go", "go.mod", "go.sum", "go.work", "go.work.sum"}
-	g.commands = []*cmd{
-		{
+	g.tooling = map[string]*cmd{
+		"mod": {
 			regex:      `(?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+)(.(?P<patch>[0-9]+))?))`,
 			getVersion: g.getVersion,
 		},
-		{
+		"go": {
 			executable: "go",
 			args:       []string{"version"},
 			regex:      `(?:go(?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+)(.(?P<patch>[0-9]+))?)))`,
 		},
 	}
+	g.defaultTooling = []string{"mod", "go"}
 	g.versionURLTemplate = "https://golang.org/doc/go{{ .Major }}.{{ .Minor }}"
 
 	return g.Language.Enabled()
