@@ -3,7 +3,7 @@ package segments
 import (
 	"slices"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 )
 
 type Mojo struct {
@@ -17,14 +17,15 @@ func (m *Mojo) Template() string {
 
 func (m *Mojo) Enabled() bool {
 	m.extensions = []string{"*.🔥", "*.mojo", "mojoproject.toml"}
-	m.commands = []*cmd{
-		{
+	m.tooling = map[string]*cmd{
+		"mojo": {
 			executable: "mojo",
 			args:       []string{"--version"},
 			regex:      `(?:mojo (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+))))`,
 		},
 	}
-	m.displayMode = m.props.GetString(DisplayMode, DisplayModeEnvironment)
+	m.defaultTooling = []string{"mojo"}
+	m.displayMode = m.options.String(DisplayMode, DisplayModeEnvironment)
 	m.Language.loadContext = m.loadContext
 	m.Language.inContext = m.inContext
 
@@ -32,7 +33,7 @@ func (m *Mojo) Enabled() bool {
 }
 
 func (m *Mojo) loadContext() {
-	if !m.props.GetBool(FetchVirtualEnv, true) {
+	if !m.options.Bool(FetchVirtualEnv, true) {
 		return
 	}
 
@@ -51,7 +52,7 @@ func (m *Mojo) inContext() bool {
 func (m *Mojo) canUseVenvName(name string) bool {
 	defaultNames := []string{"default"}
 
-	if m.props.GetBool(properties.DisplayDefault, true) ||
+	if m.options.Bool(options.DisplayDefault, true) ||
 		!slices.Contains(defaultNames, name) {
 		return true
 	}
